@@ -2,10 +2,11 @@
 
 
 APP_NAME = "presidio_cli"
-APP_VERSION = "0.0.3"
+APP_VERSION = "0.0.4"
 APP_DESCRIPTION = __doc__
+SHELL_NAME = "presidio"
 
-__author__ = u"Dawid Rycerz, Tomasz Szoszorek"
+__author__ = u"Insights Engineering"
 __author_email__=u"basel.nestcicd@roche.com"
 __copyright__ = u"Copyright 2022, F. Hoffman-La Roche Ltd"
 __license__ = "Apache 2.0"
